<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>PdfLinkDelegate</name>
    <message>
        <source>Page %1 location %2, %3 zoom %4</source>
        <translation>Sida %1 plats %2, %3 zoom %4</translation>
    </message>
</context>
<context>
    <name>AlertDialog</name>
    <message>
        <source>Alert Dialog</source>
        <translation>Larmdialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Autentisering krävs</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Log In</source>
        <translation>Logga in</translation>
    </message>
</context>
<context>
    <name>ConfirmDialog</name>
    <message>
        <source>Confirm Dialog</source>
        <translation>Bekräftelsedialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>PromptDialog</name>
    <message>
        <source>Prompt Dialog</source>
        <translation>Promptdialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>ColorDialog</name>
    <message>
        <source>Color Picker Dialog</source>
        <translation>Färgväljaredialog</translation>
    </message>
    <message>
        <source>Copy color</source>
        <translation>Kopiera färg</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Verkställ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>QWebEnginePage</name>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Reload and Bypass Cache</source>
        <translation>Uppdatera och kringgå cache</translation>
    </message>
    <message>
        <source>Open link in this window</source>
        <translation>Öppna länk i detta fönster</translation>
    </message>
    <message>
        <source>Open link in new background tab</source>
        <translation>Öppna länk i ny bakgrundsflik</translation>
    </message>
    <message>
        <source>Toggle Play/Pause</source>
        <translation>Växla Spela upp/Paus</translation>
    </message>
    <message>
        <source>Toggle Mute</source>
        <translation>Växla volym</translation>
    </message>
    <message>
        <source>Close Page</source>
        <translation>Stäng sida</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Avmarkera</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Fet stil</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Understruken</translation>
    </message>
    <message>
        <source>&amp;Strikethrough</source>
        <translation>&amp;Genomstruken</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Justera &amp;vänster</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Justera &amp;mitten</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Justera &amp;höger</translation>
    </message>
    <message>
        <source>Align &amp;Justified</source>
        <translation>Justera &amp;marginal</translation>
    </message>
    <message>
        <source>&amp;Indent</source>
        <translation>&amp;Dra in</translation>
    </message>
    <message>
        <source>&amp;Outdent</source>
        <translation>Dra &amp;ut</translation>
    </message>
    <message>
        <source>Insert &amp;Ordered List</source>
        <translation>Infoga &amp;ordnad lista</translation>
    </message>
    <message>
        <source>Insert &amp;Unordered List</source>
        <translation>Infoga oo&amp;rdnad lista</translation>
    </message>
    <message>
        <source>Change text direction left to right</source>
        <translation>Byt textriktning vänster till höger</translation>
    </message>
    <message>
        <source>Change text direction right to left</source>
        <translation>Byt textriktning höger till vänster</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page? Changes that you made may not be saved.</source>
        <translation>Är du säker på att du vill lämna denna sida? Ändringar som du har gjort kanske inte kommer att sparas.</translation>
    </message>
</context>
<context>
    <name>FilePickerController</name>
    <message>
        <source>Accepted types (%1)</source>
        <translation>Accepterade typer (%1)</translation>
    </message>
</context>
<context>
    <name>DownloadInterruptReason</name>
    <message>
        <source>Unknown reason or not interrupted</source>
        <translation>Okänd anledning eller inte avbruten</translation>
    </message>
    <message>
        <source>General file operation failure</source>
        <translation>Allmänt filåtgärdsfel</translation>
    </message>
    <message>
        <source>The file cannot be written locally, due to access restrictions</source>
        <translation>Filen kan inte skrivas lokalt på grund av åtkomstbegränsningar</translation>
    </message>
    <message>
        <source>Insufficient space on the target drive</source>
        <translation>Otillräckligt utrymme på målenheten</translation>
    </message>
    <message>
        <source>The directory or file name is too long</source>
        <translation>Katalog- eller filnamnet är för långt</translation>
    </message>
    <message>
        <source>The file size exceeds the file system limitation</source>
        <translation>Filstorleken överstiger filsystemets gräns</translation>
    </message>
    <message>
        <source>The file is infected with a virus</source>
        <translation>Filen är infekterad med ett virus</translation>
    </message>
    <message>
        <source>Temporary problem (for example file in use, or too many open files)</source>
        <translation>Temporärt problem (till exempel att filen används eller för många öppna filer)</translation>
    </message>
    <message>
        <source>The file was blocked due to local policy</source>
        <translation>Filen blockerades på grund av lokal policy</translation>
    </message>
    <message>
        <source>Checking the safety of the download failed due to unexpected reasons</source>
        <translation>Kontroll av säkerheten för hämtningen misslyckades på grund av oväntade anledningar</translation>
    </message>
    <message>
        <source>File seek past the end of a file (resuming previously interrupted download)</source>
        <translation>Filsökningen gick förbi slutet på en fil (återupptog tidigare avbruten hämtning)</translation>
    </message>
    <message>
        <source>The partial file did not match the expected hash</source>
        <translation>Partiella filen matchade inte förväntad kontrollsumma</translation>
    </message>
    <message>
        <source>General network failure</source>
        <translation>Allmänt nätverksfel</translation>
    </message>
    <message>
        <source>The network operation has timed out</source>
        <translation>Nätverksåtgärden har gått över tidsgränsen</translation>
    </message>
    <message>
        <source>The network connection has been terminated</source>
        <translation>Nätverksanslutningen har terminerats</translation>
    </message>
    <message>
        <source>The server has gone down</source>
        <translation>Servern har gått ner</translation>
    </message>
    <message>
        <source>The network request was invalid (for example, the URL or scheme is invalid)</source>
        <translation>Nätverksbegäran var ogiltig (till exempel att URLen eller schemat var ogiltigt)</translation>
    </message>
    <message>
        <source>General server failure</source>
        <translation>Allmänt serverfel</translation>
    </message>
    <message>
        <source>The server does not have the requested data</source>
        <translation>Servern har inte begärt data</translation>
    </message>
    <message>
        <source>The server did not authorize access to the resource</source>
        <translation>Servern godkände inte åtkomst till resursen</translation>
    </message>
    <message>
        <source>A problem with the server certificate occurred</source>
        <translation>Ett problem med servercertifikatet inträffade</translation>
    </message>
    <message>
        <source>Access forbidden by the server</source>
        <translation>Åtkomst förbjuden av servern</translation>
    </message>
    <message>
        <source>Unexpected server response</source>
        <translation>Oväntat serversvar</translation>
    </message>
    <message>
        <source>Download canceled by the user</source>
        <translation>Hämtningen avbröts av användaren</translation>
    </message>
</context>
<context>
    <name>RenderViewContextMenuQt</name>
    <message>
        <source>Back</source>
        <translation>Bakåt</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Framåt</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Gör om</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Markera allt</translation>
    </message>
    <message>
        <source>Paste and match style</source>
        <translation>Klistra in och matcha stilen</translation>
    </message>
    <message>
        <source>Open link in new window</source>
        <translation>Öppna länk i nytt fönster</translation>
    </message>
    <message>
        <source>Open link in new tab</source>
        <translation>Öppna länk i ny flik</translation>
    </message>
    <message>
        <source>Copy link address</source>
        <translation>Kopiera länkadress</translation>
    </message>
    <message>
        <source>Save link</source>
        <translation>Spara länk</translation>
    </message>
    <message>
        <source>Copy image</source>
        <translation>Kopiera bild</translation>
    </message>
    <message>
        <source>Copy image address</source>
        <translation>Kopiera bildadress</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Spara bild</translation>
    </message>
    <message>
        <source>Copy media address</source>
        <translation>Kopiera mediaadress</translation>
    </message>
    <message>
        <source>Show controls</source>
        <translation>Visa kontroller</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Slinga</translation>
    </message>
    <message>
        <source>Save media</source>
        <translation>Spara media</translation>
    </message>
    <message>
        <source>Inspect</source>
        <translation>Inspektera</translation>
    </message>
    <message>
        <source>Exit full screen</source>
        <translation>Avsluta helskärm</translation>
    </message>
    <message>
        <source>Save page</source>
        <translation>Spara sida</translation>
    </message>
    <message>
        <source>View page source</source>
        <translation>Visa sidkälla</translation>
    </message>
</context>
<context>
    <name>WebContentsAdapter</name>
    <message>
        <source>HTTP-POST data can only be sent over HTTP(S) protocol</source>
        <translation>HTTP-POST-data kan endast skickas över HTTP(S)-protokollet</translation>
    </message>
</context>
<context>
    <name>QPdfLinkModel</name>
    <message>
        <source>Page %1 location %2, %3 zoom %4</source>
        <translation>Sida %1 plats %2, %3 zoom %4</translation>
    </message>
</context>
<context>
    <name>QQuickPdfDocument</name>
    <message>
        <source>no error</source>
        <translation>inget fel</translation>
    </message>
    <message>
        <source>data not yet available</source>
        <translation>data ännu inte tillgängligt</translation>
    </message>
    <message>
        <source>file not found</source>
        <translation>filen hittades inte</translation>
    </message>
    <message>
        <source>invalid file format</source>
        <translation>ogiltig filformat</translation>
    </message>
    <message>
        <source>incorrect password</source>
        <translation>felaktigt lösenord</translation>
    </message>
    <message>
        <source>unsupported security scheme</source>
        <translation>säkerhetsschemat stöds inte</translation>
    </message>
    <message>
        <source>unknown error</source>
        <translation>okänt fel</translation>
    </message>
</context>
<context>
    <name>UIDelegatesManager</name>
    <message>
        <source>Javascript Alert - %1</source>
        <translation>Javascript-larm - %1</translation>
    </message>
    <message>
        <source>Javascript Confirm - %1</source>
        <translation>Javascript-bekräfta - %1</translation>
    </message>
    <message>
        <source>Javascript Prompt - %1</source>
        <translation>Javascript-prompt - %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave this page?</source>
        <translation>Är du säker på att du vill lämna denna sida?</translation>
    </message>
    <message>
        <source>Changes that you made may not be saved.</source>
        <translation>Ändringar som du har gjort kommer inte att sparas.</translation>
    </message>
    <message>
        <source>Connect to proxy &quot;%1&quot; using:</source>
        <translation>Anslut till proxy &quot;%1&quot; med:</translation>
    </message>
    <message>
        <source>Enter username and password for &quot;%1&quot; at %2://%3</source>
        <translation>Ange användarnamn och lösenord för &quot;%1&quot; på %2://%3</translation>
    </message>
</context>
<context>
    <name>QWebEngineView</name>
    <message>
        <source>Select folder to upload</source>
        <translation>Välj mapp att skicka upp</translation>
    </message>
</context>
<context>
    <name>QtWebEngineWidgetUI::TouchSelectionMenuWidget</name>
    <message>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
